@@ -95,7 +95,14 @@ class ViewsMap(Mapper):
         )
         self.n_textbox = 0
 
-    def add_layer(self, gdf, cmap=None, inform_colorbar=False, **kwargs):
+    def add_layer(
+        self,
+        gdf,
+        cmap=None,
+        inform_colorbar=False,
+        suppress_textbox=False,
+        **kwargs,
+    ):
         """Add a geopandas plot to a new layer.
 
         Overrides method in parent, adding the default views textbox
@@ -107,24 +114,30 @@ class ViewsMap(Mapper):
         cmap: Optional matplotlib colormap object or string reference
             (e.g. "viridis").
         inform_colorbar: Set or overwrite colorbar with the current layer.
+            Not applicable when `color` is supplied in the kwargs.
+        suppress_textbox: Bool indicating whether to suppress the drawing of
+            a views-textbox.
         **kwargs: Geopandas `.plot` keyword arguments.
         """
-        colormap = self.cmap if cmap is None else cmap
-        # If inform_colorbar, replace cax if exists and set with vmin, vmax.
-        if inform_colorbar and "column" in kwargs:
-            if hasattr(self, "cax"):
-                self.cax.remove()
-            if "vmin" not in kwargs:
-                self.vmin = gdf[kwargs["column"]].min()
-            else:
-                self.vmin = kwargs["vmin"]
-            if "vmax" not in kwargs:
-                self.vmax = gdf[kwargs["column"]].max()
-            else:
-                self.vmax = kwargs["vmax"]
-            Mapper.add_colorbar(self, colormap, self.vmin, self.vmax)
+        if "color" in kwargs:
+            colormap = None
+        else:
+            colormap = self.cmap if cmap is None else cmap
+            # If inform_colorbar, replace cax if exists and set with vmin vmax.
+            if inform_colorbar and "column" in kwargs:
+                if hasattr(self, "cax"):
+                    self.cax.remove()
+                if "vmin" not in kwargs:
+                    self.vmin = gdf[kwargs["column"]].min()
+                else:
+                    self.vmin = kwargs["vmin"]
+                if "vmax" not in kwargs:
+                    self.vmax = gdf[kwargs["column"]].max()
+                else:
+                    self.vmax = kwargs["vmax"]
+                Mapper.add_colorbar(self, colormap, self.vmin, self.vmax)
         self.ax = gdf.plot(ax=self.ax, cmap=colormap, **kwargs)
-        if self.n_textbox == 0:
+        if self.n_textbox == 0 and not suppress_textbox:
             Mapper.add_views_textbox(self, text=self.label, textsize=16)
             self.n_textbox += 1
         return self
